@@ -54,14 +54,14 @@ getitem getline getlines getcase getstepsvar tell wash flattenbox enrichbox filt
 $configfile $mypath $exeonfiles $generatechance $file $preventsim $fileconfig $outfile $toshell $report 
 $simnetwork @themereports @simtitles @reporttitles @simdata @retrievedata 
 @keepcolumns @weights @weightsaim @varthemes_report @varthemes_variations @varthemes_steps 
-@rankdata @rankcolumn @reporttempsdata @reportcomfortdata @reportdata 
+@rankdata @rankcolumn @reporttempsdata @reportcomfortdata $reportdata 
 @report_loadsortemps @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns 
 @files_to_filter @filter_reports @base_columns @maketabledata @filter_columns %vals 
 @sweeps @mediumiters @varinumbers @caseseed @chanceseed @chancedata $dimchance $tee @pars_tocheck retrieve
 $target 
 );
 
-$VERSION = '0.41.1'; # our $VERSION = '';
+$VERSION = '0.43.0'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
